pub struct BinUnpackingJob {
pub render_binned_mesh_instance_buffer: Buffer,
pub bin_index_to_indirect_parameters_offset_buffer: Buffer,
pub bin_unpacking_metadata_index: BinUnpackingMetadataIndex,
pub mesh_instance_count: u32,
}Expand description
CPU-side information needed to construct the bind groups and issue the
dispatch for the unpack_bins shader, for a single batch set.
Fields
render_binned_mesh_instance_buffer: BufferThe GPU buffer of GpuRenderBinnedMeshInstances corresponding to the
mesh instances that this batch set contains.
bin_index_to_indirect_parameters_offset_buffer: BufferThe GPU buffer that maps each bin index to the index of the indirect drawing parameters for that bin, relative to the first such indirect drawing parameters for this batch set.
bin_unpacking_metadata_index: BinUnpackingMetadataIndexThe index of this batch set’s GpuBinUnpackingMetadata in the
BinUnpackingBuffers::bin_unpacking_metadata buffer.
mesh_instance_count: u32The total number of mesh instances in this batch set.